#############################
The PyMESA-Web Python Package
#############################

.. image:: https://img.shields.io/github/license/rhdtownsend/pymesa-web
   :alt: GitHub
   :target: https://github.com/rhdtownsend/pymesa-web/blob/main/COPYING
.. image:: https://img.shields.io/github/issues/rhdtownsend/pymesa-web
   :alt: GitHub issues
   :target: https://github.com/rhdtownsend/pymesa-web/issues

Overview
========
	    
PyMESA-Web is a Python package that provides support for the `MESA-Web
stellar evolution portal
<http://user.astro.wisc.edu/~townsend/static.php?ref=mesa-web>`__. Releases
are hosted on `PyPI <https://pypi.org/>`__; therefore, the easiest way
to install is to use `pip` or a similar tool::

  pip install pymesa-web
